pub struct LayoutTracker { /* private fields */ }Implementations
Sourceimpl LayoutTracker
impl LayoutTracker
pub fn new() -> Self
pub fn current(&self, handle: ResourceHandle) -> ImageLayout
pub fn set(&mut self, handle: ResourceHandle, layout: ImageLayout)
Sourcepub fn plan_transition(
&mut self,
pool: &ResourcePool,
transitions: impl IntoIterator<Item = (ResourceHandle, ImageLayout)>,
) -> &[ImageMemoryBarrier2<'static>]
pub fn plan_transition( &mut self, pool: &ResourcePool, transitions: impl IntoIterator<Item = (ResourceHandle, ImageLayout)>, ) -> &[ImageMemoryBarrier2<'static>]
Computes the list of required barriers for transitioning to the new layouts
and records the new state in the tracker. Does not record GPU commands itself -
the caller must pass the returned slice to cmd_pipeline_barrier2
(see RenderGraph::execute), or ignore it if it decides to skip the transition.
pub fn invalidate(&mut self, handles: &[ResourceHandle])